[−][src]Module snarkos_polycommit::marlin_pc
Polynomial commitment scheme from [KZG10] that enforces strict degree bounds and (optionally) enables hiding commitments by following the approach outlined in [CHMMVW20, "Marlin"].
Structs
| Commitment | Commitment to a polynomial that optionally enforces a degree bound. |
| CommitterKey |
|
| MarlinKZG10 | Polynomial commitment based on [KZG10], with degree enforcement, batching, and (optional) hiding property taken from [CHMMVW20, “Marlin”]. |
| Randomness |
|
| VerifierKey |
|
Type Definitions
| UniversalParams |
|